@@ -21,6 +21,11 @@ class XgbWrapper(object):
         xgb_train = xgb.DMatrix(X_train, label=y_train)  
         xgb_valid = xgb.DMatrix(X_val, label=y_val)
         
+        num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
+        early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
+        verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
+        
+        
         self.clf = xgb.train(params=self.params, 
                       dtrain=xgb_train,
                       evals=[(xgb_train, 'train'), (xgb_valid, 'valid')],
@@ -39,6 +44,10 @@ class XgbWrapper(object):
         
         data_train = xgb.DMatrix(X, label=y)  
         
+        num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
+        early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
+        verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
+        
         if kf_type == 'kf':
             kf = KFold(n_splits = nfolds, shuffle=True, random_state=seed)
         else:
@@ -73,11 +82,15 @@ class LightGBMWrapper(object):
         
         lgb_train = lgb.Dataset(X_train,y_train)  
         lgb_valid = lgb.Dataset(X_val,y_val)
-                
+        
+        num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
+        early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
+        verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
+        
         self.clf = lgb.train(params=self.params, 
                          train_set=lgb_train,
                          valid_sets=[lgb_train, lgb_valid],
-                         num_boost_round=num_boost_round,   
+                         num_boost_round=num_boost_round
                          verbose_eval=verbose_eval,
                          early_stopping_rounds=early_stopping_rounds,
                         )
@@ -93,6 +106,11 @@ class LightGBMWrapper(object):
         
         data_train = lgb.Dataset(X, y)  
         
+        num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
+        early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
+        verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
+        
+        
         if kf_type == 'kf':
             kf = KFold(n_splits = nfolds, shuffle=True, random_state=seed)
         else:
@@ -125,6 +143,11 @@ class CatboostWrapper(object):
     def train(self, X_train, y_train, X_val, y_val, num_boost_round=100000, early_stopping_rounds=100, verbose=100):
         cb_train = cb.Pool(X_train,y_train)  
         cb_valid = cb.Pool(X_val,y_val)
+        
+        num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
+        early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
+        verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
+        
         self.clf = cb.train(dtrain=cb_train, 
                             params=self.params, 
                             evals=[cb_train, cb_valid],
@@ -138,6 +161,7 @@ class CatboostWrapper(object):
     
     def predict_proba(self, x):
         return self.clf.predict_proba(x)
+
 class SklearnWrapper(object):
     def __init__(self, clf, seed=0, params={}):
         params['random_state'] = seed
@@ -153,4 +177,4 @@ class SklearnWrapper(object):
             return self.clf.predict(x)
 
     def predict_proba(self, x):
-        return self.clf.predict_proba(x)
+        return self.clf.predict_proba(x)
\ No newline at end of file
